@@ -33,3 +33,23 @@ d <- data.frame(x=rnorm(10), y=rnorm(10), lab=LETTERS[1:10])
 p <- ggplot(d, aes(x, y)) + geom_text(aes(label=lab), size=5)
 set_font(p, family="Times", fontface="italic", color='firebrick')
 
+## ----fig.width=6, fig.height=3------------------------------------------------
+library(ggplot2)
+library(ggfun)
+p <- ggplot(mtcars, aes(disp, drat)) + 
+  geom_point() + 
+  facet_grid(cols=vars(am), rows=vars(cyl))
+p + facet_set(label=c(`0`="Zero", `6`="Six"))
+
+## -----------------------------------------------------------------------------
+p + facet_set(label=label_both)
+
+## -----------------------------------------------------------------------------
+p + facet_set(label="TEST")
+
+## ----eval=FALSE---------------------------------------------------------------
+#  ## please try:
+#  
+#  ggplotify::as.ggplot(~barplot(1:10, col=rainbow(10))) +
+#    facet_set('a barplot in base')
+
